@@ -10,6 +10,6 @@ class TestTfidfEncoder(unittest.TestCase):
         text = [''.join(random.choices(string.printable, k=random.randint(5,500))) for x in range(1000)]
 
         enc = TfidfEncoder()
-        enc.prepare_encoder(text)
+        enc.prepare(text)
         encoded_data = enc.encode(text)
         print(encoded_data)
